@@ -1,7 +1,7 @@
 package App::rimetadb;
 
-our $DATE = '2016-01-03'; # DATE
-our $VERSION = '0.15'; # VERSION
+our $DATE = '2016-03-10'; # DATE
+our $VERSION = '0.16'; # VERSION
 
 use 5.010001;
 use strict;
@@ -65,8 +65,8 @@ sub _cleanser {
 }
 
 sub _json {
-    require JSON;
-    state $json = JSON->new->allow_nonref;
+    require JSON::MaybeXS;
+    state $json = JSON::MaybeXS->new->allow_nonref;
     $json;
 }
 
@@ -658,16 +658,12 @@ App::rimetadb - Manage a Rinci metadata database
 
 =head1 VERSION
 
-This document describes version 0.15 of App::rimetadb (from Perl distribution App-rimetadb), released on 2015-01-03.
+This document describes version 0.16 of App::rimetadb (from Perl distribution App-rimetadb), released on 2016-03-10.
 
 =head1 SYNOPSIS
 
 See the included CLI script L<rimetadb>.
 
-=head1 SEE ALSO
-
-L<Rinci>
-
 =head1 FUNCTIONS
 
 
@@ -675,7 +671,7 @@ L<Rinci>
 
 List function arguments.
 
-This function is not exportable.
+This function is not exported.
 
 Arguments ('*' denotes required arguments):
 
@@ -718,7 +714,7 @@ Return value:  (any)
 
 Delete a package or function metadata.
 
-This function is not exportable.
+This function is not exported.
 
 Arguments ('*' denotes required arguments):
 
@@ -763,7 +759,7 @@ Return value:  (any)
 
 List functions.
 
-This function is not exportable.
+This function is not exported.
 
 Arguments ('*' denotes required arguments):
 
@@ -808,7 +804,7 @@ Return value:  (any)
 
 List packages.
 
-This function is not exportable.
+This function is not exported.
 
 Arguments ('*' denotes required arguments):
 
@@ -853,7 +849,7 @@ Return value:  (any)
 
 Show some statistics.
 
-This function is not exportable.
+This function is not exported.
 
 No arguments.
 
@@ -873,7 +869,7 @@ Return value:  (any)
 
 Add/update a package or function metadata.
 
-This function is not exportable.
+This function is not exported.
 
 Arguments ('*' denotes required arguments):
 
@@ -927,7 +923,7 @@ Update Rinci metadata database from local Perl modules.
 This routine scans Perl modules, load them, and update the database using Rinci
 metadata from each modules into the database.
 
-This function is not exportable.
+This function is not exported.
 
 This function supports dry-run operation.
 
@@ -1035,7 +1031,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/App-rimeta
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-App-UpdateRinciMetadataDb>.
+Source repository is at L<https://github.com/perlancar/perl-App-rimetadb>.
 
 =head1 BUGS
 
@@ -1045,6 +1041,10 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+L<Rinci>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
